class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QAbstractMessageHandler(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QAbstractMessageHandler.__init__(QObject parent = None)'''
    def handleMessage(self, type, description, identifier, sourceLocation):
        '''abstract void QAbstractMessageHandler.handleMessage(QtMsgType type, QString description, QUrl identifier, QSourceLocation sourceLocation)'''
    def message(self, type, description, identifier = QUrl(), sourceLocation = QSourceLocation()):
        '''void QAbstractMessageHandler.message(QtMsgType type, QString description, QUrl identifier = QUrl(), QSourceLocation sourceLocation = QSourceLocation())'''


class QAbstractUriResolver(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QAbstractUriResolver.__init__(QObject parent = None)'''
    def resolve(self, relative, baseURI):
        '''abstract QUrl QAbstractUriResolver.resolve(QUrl relative, QUrl baseURI)'''
        return QUrl()


class QXmlNodeModelIndex():
    """"""
    # Enum QXmlNodeModelIndex.DocumentOrder
    Precedes = 0
    Is = 0
    Follows = 0

    # Enum QXmlNodeModelIndex.NodeKind
    Attribute = 0
    Comment = 0
    Document = 0
    Element = 0
    Namespace = 0
    ProcessingInstruction = 0
    Text = 0

    def __init__(self):
        '''void QXmlNodeModelIndex.__init__()'''
    def __init__(self, other):
        '''void QXmlNodeModelIndex.__init__(QXmlNodeModelIndex other)'''
    def __hash__(self):
        '''int QXmlNodeModelIndex.__hash__()'''
        return int()
    def isNull(self):
        '''bool QXmlNodeModelIndex.isNull()'''
        return bool()
    def additionalData(self):
        '''int QXmlNodeModelIndex.additionalData()'''
        return int()
    def model(self):
        '''QAbstractXmlNodeModel QXmlNodeModelIndex.model()'''
        return QAbstractXmlNodeModel()
    def internalPointer(self):
        '''object QXmlNodeModelIndex.internalPointer()'''
        return object()
    def data(self):
        '''int QXmlNodeModelIndex.data()'''
        return int()
    def __ne__(self, other):
        '''bool QXmlNodeModelIndex.__ne__(QXmlNodeModelIndex other)'''
        return bool()
    def __eq__(self, other):
        '''bool QXmlNodeModelIndex.__eq__(QXmlNodeModelIndex other)'''
        return bool()


class QAbstractXmlNodeModel():
    """"""
    # Enum QAbstractXmlNodeModel.SimpleAxis
    Parent = 0
    FirstChild = 0
    PreviousSibling = 0
    NextSibling = 0

    def __init__(self):
        '''void QAbstractXmlNodeModel.__init__()'''
    def createIndex(self, data):
        '''QXmlNodeModelIndex QAbstractXmlNodeModel.createIndex(int data)'''
        return QXmlNodeModelIndex()
    def createIndex(self, data, additionalData):
        '''QXmlNodeModelIndex QAbstractXmlNodeModel.createIndex(int data, int additionalData)'''
        return QXmlNodeModelIndex()
    def createIndex(self, pointer, additionalData = 0):
        '''QXmlNodeModelIndex QAbstractXmlNodeModel.createIndex(object pointer, int additionalData = 0)'''
        return QXmlNodeModelIndex()
    def attributes(self, element):
        '''abstract list-of-QXmlNodeModelIndex QAbstractXmlNodeModel.attributes(QXmlNodeModelIndex element)'''
        return [QXmlNodeModelIndex()]
    def nextFromSimpleAxis(self, axis, origin):
        '''abstract QXmlNodeModelIndex QAbstractXmlNodeModel.nextFromSimpleAxis(QAbstractXmlNodeModel.SimpleAxis axis, QXmlNodeModelIndex origin)'''
        return QXmlNodeModelIndex()
    def sourceLocation(self, index):
        '''QSourceLocation QAbstractXmlNodeModel.sourceLocation(QXmlNodeModelIndex index)'''
        return QSourceLocation()
    def nodesByIdref(self, NCName):
        '''abstract list-of-QXmlNodeModelIndex QAbstractXmlNodeModel.nodesByIdref(QXmlName NCName)'''
        return [QXmlNodeModelIndex()]
    def elementById(self, NCName):
        '''abstract QXmlNodeModelIndex QAbstractXmlNodeModel.elementById(QXmlName NCName)'''
        return QXmlNodeModelIndex()
    def namespaceBindings(self, n):
        '''abstract list-of-QXmlName QAbstractXmlNodeModel.namespaceBindings(QXmlNodeModelIndex n)'''
        return [QXmlName()]
    def typedValue(self, n):
        '''abstract QVariant QAbstractXmlNodeModel.typedValue(QXmlNodeModelIndex n)'''
        return QVariant()
    def stringValue(self, n):
        '''abstract QString QAbstractXmlNodeModel.stringValue(QXmlNodeModelIndex n)'''
        return QString()
    def name(self, ni):
        '''abstract QXmlName QAbstractXmlNodeModel.name(QXmlNodeModelIndex ni)'''
        return QXmlName()
    def root(self, n):
        '''abstract QXmlNodeModelIndex QAbstractXmlNodeModel.root(QXmlNodeModelIndex n)'''
        return QXmlNodeModelIndex()
    def compareOrder(self, ni1, ni2):
        '''abstract QXmlNodeModelIndex.DocumentOrder QAbstractXmlNodeModel.compareOrder(QXmlNodeModelIndex ni1, QXmlNodeModelIndex ni2)'''
        return QXmlNodeModelIndex.DocumentOrder()
    def kind(self, ni):
        '''abstract QXmlNodeModelIndex.NodeKind QAbstractXmlNodeModel.kind(QXmlNodeModelIndex ni)'''
        return QXmlNodeModelIndex.NodeKind()
    def documentUri(self, ni):
        '''abstract QUrl QAbstractXmlNodeModel.documentUri(QXmlNodeModelIndex ni)'''
        return QUrl()
    def baseUri(self, ni):
        '''abstract QUrl QAbstractXmlNodeModel.baseUri(QXmlNodeModelIndex ni)'''
        return QUrl()


class QXmlItem():
    """"""
    def __init__(self):
        '''void QXmlItem.__init__()'''
    def __init__(self, other):
        '''void QXmlItem.__init__(QXmlItem other)'''
    def __init__(self, node):
        '''void QXmlItem.__init__(QXmlNodeModelIndex node)'''
    def __init__(self, atomicValue):
        '''void QXmlItem.__init__(QVariant atomicValue)'''
    def toNodeModelIndex(self):
        '''QXmlNodeModelIndex QXmlItem.toNodeModelIndex()'''
        return QXmlNodeModelIndex()
    def toAtomicValue(self):
        '''QVariant QXmlItem.toAtomicValue()'''
        return QVariant()
    def isAtomicValue(self):
        '''bool QXmlItem.isAtomicValue()'''
        return bool()
    def isNode(self):
        '''bool QXmlItem.isNode()'''
        return bool()
    def isNull(self):
        '''bool QXmlItem.isNull()'''
        return bool()


class QAbstractXmlReceiver():
    """"""
    def __init__(self):
        '''void QAbstractXmlReceiver.__init__()'''
    def endOfSequence(self):
        '''abstract void QAbstractXmlReceiver.endOfSequence()'''
    def startOfSequence(self):
        '''abstract void QAbstractXmlReceiver.startOfSequence()'''
    def namespaceBinding(self, name):
        '''abstract void QAbstractXmlReceiver.namespaceBinding(QXmlName name)'''
    def atomicValue(self, value):
        '''abstract void QAbstractXmlReceiver.atomicValue(QVariant value)'''
    def processingInstruction(self, target, value):
        '''abstract void QAbstractXmlReceiver.processingInstruction(QXmlName target, QString value)'''
    def endDocument(self):
        '''abstract void QAbstractXmlReceiver.endDocument()'''
    def startDocument(self):
        '''abstract void QAbstractXmlReceiver.startDocument()'''
    def characters(self, value):
        '''abstract void QAbstractXmlReceiver.characters(QStringRef value)'''
    def comment(self, value):
        '''abstract void QAbstractXmlReceiver.comment(QString value)'''
    def attribute(self, name, value):
        '''abstract void QAbstractXmlReceiver.attribute(QXmlName name, QStringRef value)'''
    def endElement(self):
        '''abstract void QAbstractXmlReceiver.endElement()'''
    def startElement(self, name):
        '''abstract void QAbstractXmlReceiver.startElement(QXmlName name)'''


class QSimpleXmlNodeModel(QAbstractXmlNodeModel):
    """"""
    def __init__(self, namePool):
        '''void QSimpleXmlNodeModel.__init__(QXmlNamePool namePool)'''
    def nodesByIdref(self, idref):
        '''list-of-QXmlNodeModelIndex QSimpleXmlNodeModel.nodesByIdref(QXmlName idref)'''
        return [QXmlNodeModelIndex()]
    def elementById(self, id):
        '''QXmlNodeModelIndex QSimpleXmlNodeModel.elementById(QXmlName id)'''
        return QXmlNodeModelIndex()
    def stringValue(self, node):
        '''QString QSimpleXmlNodeModel.stringValue(QXmlNodeModelIndex node)'''
        return QString()
    def namespaceBindings(self):
        '''QXmlNodeModelIndex QSimpleXmlNodeModel.namespaceBindings()'''
        return QXmlNodeModelIndex()
    def namePool(self):
        '''QXmlNamePool QSimpleXmlNodeModel.namePool()'''
        return QXmlNamePool()
    def baseUri(self, node):
        '''QUrl QSimpleXmlNodeModel.baseUri(QXmlNodeModelIndex node)'''
        return QUrl()


class QSourceLocation():
    """"""
    def __init__(self):
        '''void QSourceLocation.__init__()'''
    def __init__(self, other):
        '''void QSourceLocation.__init__(QSourceLocation other)'''
    def __init__(self, u, line = None, column = None):
        '''void QSourceLocation.__init__(QUrl u, int line = -1, int column = -1)'''
    def __hash__(self):
        '''int QSourceLocation.__hash__()'''
        return int()
    def isNull(self):
        '''bool QSourceLocation.isNull()'''
        return bool()
    def setUri(self, newUri):
        '''void QSourceLocation.setUri(QUrl newUri)'''
    def uri(self):
        '''QUrl QSourceLocation.uri()'''
        return QUrl()
    def setLine(self, newLine):
        '''void QSourceLocation.setLine(int newLine)'''
    def line(self):
        '''int QSourceLocation.line()'''
        return int()
    def setColumn(self, newColumn):
        '''void QSourceLocation.setColumn(int newColumn)'''
    def column(self):
        '''int QSourceLocation.column()'''
        return int()
    def __ne__(self, other):
        '''bool QSourceLocation.__ne__(QSourceLocation other)'''
        return bool()
    def __eq__(self, other):
        '''bool QSourceLocation.__eq__(QSourceLocation other)'''
        return bool()


class QXmlSerializer(QAbstractXmlReceiver):
    """"""
    def __init__(self, query, outputDevice):
        '''void QXmlSerializer.__init__(QXmlQuery query, QIODevice outputDevice)'''
    def codec(self):
        '''QTextCodec QXmlSerializer.codec()'''
        return QTextCodec()
    def setCodec(self, codec):
        '''void QXmlSerializer.setCodec(QTextCodec codec)'''
    def outputDevice(self):
        '''QIODevice QXmlSerializer.outputDevice()'''
        return QIODevice()
    def endOfSequence(self):
        '''void QXmlSerializer.endOfSequence()'''
    def startOfSequence(self):
        '''void QXmlSerializer.startOfSequence()'''
    def endDocument(self):
        '''void QXmlSerializer.endDocument()'''
    def startDocument(self):
        '''void QXmlSerializer.startDocument()'''
    def atomicValue(self, value):
        '''void QXmlSerializer.atomicValue(QVariant value)'''
    def processingInstruction(self, name, value):
        '''void QXmlSerializer.processingInstruction(QXmlName name, QString value)'''
    def attribute(self, name, value):
        '''void QXmlSerializer.attribute(QXmlName name, QStringRef value)'''
    def endElement(self):
        '''void QXmlSerializer.endElement()'''
    def startElement(self, name):
        '''void QXmlSerializer.startElement(QXmlName name)'''
    def comment(self, value):
        '''void QXmlSerializer.comment(QString value)'''
    def characters(self, value):
        '''void QXmlSerializer.characters(QStringRef value)'''
    def namespaceBinding(self, nb):
        '''void QXmlSerializer.namespaceBinding(QXmlName nb)'''


class QXmlFormatter(QXmlSerializer):
    """"""
    def __init__(self, query, outputDevice):
        '''void QXmlFormatter.__init__(QXmlQuery query, QIODevice outputDevice)'''
    def setIndentationDepth(self, depth):
        '''void QXmlFormatter.setIndentationDepth(int depth)'''
    def indentationDepth(self):
        '''int QXmlFormatter.indentationDepth()'''
        return int()
    def endOfSequence(self):
        '''void QXmlFormatter.endOfSequence()'''
    def startOfSequence(self):
        '''void QXmlFormatter.startOfSequence()'''
    def endDocument(self):
        '''void QXmlFormatter.endDocument()'''
    def startDocument(self):
        '''void QXmlFormatter.startDocument()'''
    def atomicValue(self, value):
        '''void QXmlFormatter.atomicValue(QVariant value)'''
    def processingInstruction(self, name, value):
        '''void QXmlFormatter.processingInstruction(QXmlName name, QString value)'''
    def attribute(self, name, value):
        '''void QXmlFormatter.attribute(QXmlName name, QStringRef value)'''
    def endElement(self):
        '''void QXmlFormatter.endElement()'''
    def startElement(self, name):
        '''void QXmlFormatter.startElement(QXmlName name)'''
    def comment(self, value):
        '''void QXmlFormatter.comment(QString value)'''
    def characters(self, value):
        '''void QXmlFormatter.characters(QStringRef value)'''


class QXmlName():
    """"""
    def __init__(self):
        '''void QXmlName.__init__()'''
    def __init__(self, namePool, localName, namespaceUri = QString(), prefix = QString()):
        '''void QXmlName.__init__(QXmlNamePool namePool, QString localName, QString namespaceUri = QString(), QString prefix = QString())'''
    def __init__(self):
        '''QXmlName QXmlName.__init__()'''
        return QXmlName()
    def __hash__(self):
        '''int QXmlName.__hash__()'''
        return int()
    def fromClarkName(self, clarkName, namePool):
        '''static QXmlName QXmlName.fromClarkName(QString clarkName, QXmlNamePool namePool)'''
        return QXmlName()
    def isNCName(self, candidate):
        '''static bool QXmlName.isNCName(QString candidate)'''
        return bool()
    def isNull(self):
        '''bool QXmlName.isNull()'''
        return bool()
    def __ne__(self, other):
        '''bool QXmlName.__ne__(QXmlName other)'''
        return bool()
    def __eq__(self, other):
        '''bool QXmlName.__eq__(QXmlName other)'''
        return bool()
    def toClarkName(self, query):
        '''QString QXmlName.toClarkName(QXmlNamePool query)'''
        return QString()
    def localName(self, query):
        '''QString QXmlName.localName(QXmlNamePool query)'''
        return QString()
    def prefix(self, query):
        '''QString QXmlName.prefix(QXmlNamePool query)'''
        return QString()
    def namespaceUri(self, query):
        '''QString QXmlName.namespaceUri(QXmlNamePool query)'''
        return QString()


class QXmlNamePool():
    """"""
    def __init__(self):
        '''void QXmlNamePool.__init__()'''
    def __init__(self, other):
        '''void QXmlNamePool.__init__(QXmlNamePool other)'''


class QXmlQuery():
    """"""
    # Enum QXmlQuery.QueryLanguage
    XQuery10 = 0
    XSLT20 = 0

    def __init__(self):
        '''void QXmlQuery.__init__()'''
    def __init__(self, other):
        '''void QXmlQuery.__init__(QXmlQuery other)'''
    def __init__(self, np):
        '''void QXmlQuery.__init__(QXmlNamePool np)'''
    def __init__(self, queryLanguage, pool = QXmlNamePool()):
        '''void QXmlQuery.__init__(QXmlQuery.QueryLanguage queryLanguage, QXmlNamePool pool = QXmlNamePool())'''
    def queryLanguage(self):
        '''QXmlQuery.QueryLanguage QXmlQuery.queryLanguage()'''
        return QXmlQuery.QueryLanguage()
    def networkAccessManager(self):
        '''QNetworkAccessManager QXmlQuery.networkAccessManager()'''
        return QNetworkAccessManager()
    def setNetworkAccessManager(self, newManager):
        '''void QXmlQuery.setNetworkAccessManager(QNetworkAccessManager newManager)'''
    def initialTemplateName(self):
        '''QXmlName QXmlQuery.initialTemplateName()'''
        return QXmlName()
    def setInitialTemplateName(self, name):
        '''void QXmlQuery.setInitialTemplateName(QXmlName name)'''
    def setInitialTemplateName(self, name):
        '''void QXmlQuery.setInitialTemplateName(QString name)'''
    def setFocus(self, item):
        '''void QXmlQuery.setFocus(QXmlItem item)'''
    def setFocus(self, documentURI):
        '''bool QXmlQuery.setFocus(QUrl documentURI)'''
        return bool()
    def setFocus(self, document):
        '''bool QXmlQuery.setFocus(QIODevice document)'''
        return bool()
    def setFocus(self, focus):
        '''bool QXmlQuery.setFocus(QString focus)'''
        return bool()
    def uriResolver(self):
        '''QAbstractUriResolver QXmlQuery.uriResolver()'''
        return QAbstractUriResolver()
    def setUriResolver(self, resolver):
        '''void QXmlQuery.setUriResolver(QAbstractUriResolver resolver)'''
    def evaluateToString(self):
        '''QString QXmlQuery.evaluateToString()'''
        return QString()
    def evaluateToStringList(self):
        '''QStringList QXmlQuery.evaluateToStringList()'''
        return QStringList()
    def evaluateTo(self, result):
        '''void QXmlQuery.evaluateTo(QXmlResultItems result)'''
    def evaluateTo(self, callback):
        '''bool QXmlQuery.evaluateTo(QAbstractXmlReceiver callback)'''
        return bool()
    def evaluateTo(self, target):
        '''bool QXmlQuery.evaluateTo(QStringList target)'''
        return bool()
    def evaluateTo(self, target):
        '''bool QXmlQuery.evaluateTo(QIODevice target)'''
        return bool()
    def evaluateTo(self, output):
        '''bool QXmlQuery.evaluateTo(QString output)'''
        return bool()
    def isValid(self):
        '''bool QXmlQuery.isValid()'''
        return bool()
    def bindVariable(self, name, value):
        '''void QXmlQuery.bindVariable(QXmlName name, QXmlItem value)'''
    def bindVariable(self, name):
        '''QIODevice QXmlQuery.bindVariable(QXmlName name)'''
        return QIODevice()
    def bindVariable(self, name, query):
        '''void QXmlQuery.bindVariable(QXmlName name, QXmlQuery query)'''
    def bindVariable(self, localName, value):
        '''void QXmlQuery.bindVariable(QString localName, QXmlItem value)'''
    def bindVariable(self, localName):
        '''QIODevice QXmlQuery.bindVariable(QString localName)'''
        return QIODevice()
    def bindVariable(self, localName, query):
        '''void QXmlQuery.bindVariable(QString localName, QXmlQuery query)'''
    def namePool(self):
        '''QXmlNamePool QXmlQuery.namePool()'''
        return QXmlNamePool()
    def setQuery(self, sourceCode, documentUri = QUrl()):
        '''void QXmlQuery.setQuery(QString sourceCode, QUrl documentUri = QUrl())'''
    def setQuery(self, sourceCode, documentUri = QUrl()):
        '''void QXmlQuery.setQuery(QIODevice sourceCode, QUrl documentUri = QUrl())'''
    def setQuery(self, queryURI, baseUri = QUrl()):
        '''void QXmlQuery.setQuery(QUrl queryURI, QUrl baseUri = QUrl())'''
    def messageHandler(self):
        '''QAbstractMessageHandler QXmlQuery.messageHandler()'''
        return QAbstractMessageHandler()
    def setMessageHandler(self, messageHandler):
        '''void QXmlQuery.setMessageHandler(QAbstractMessageHandler messageHandler)'''


class QXmlResultItems():
    """"""
    def __init__(self):
        '''void QXmlResultItems.__init__()'''
    def current(self):
        '''QXmlItem QXmlResultItems.current()'''
        return QXmlItem()
    def next(self):
        '''QXmlItem QXmlResultItems.next()'''
        return QXmlItem()
    def hasError(self):
        '''bool QXmlResultItems.hasError()'''
        return bool()


class QXmlSchema():
    """"""
    def __init__(self):
        '''void QXmlSchema.__init__()'''
    def networkAccessManager(self):
        '''QNetworkAccessManager QXmlSchema.networkAccessManager()'''
        return QNetworkAccessManager()
    def setNetworkAccessManager(self, networkmanager):
        '''void QXmlSchema.setNetworkAccessManager(QNetworkAccessManager networkmanager)'''
    def uriResolver(self):
        '''QAbstractUriResolver QXmlSchema.uriResolver()'''
        return QAbstractUriResolver()
    def setUriResolver(self, resolver):
        '''void QXmlSchema.setUriResolver(QAbstractUriResolver resolver)'''
    def messageHandler(self):
        '''QAbstractMessageHandler QXmlSchema.messageHandler()'''
        return QAbstractMessageHandler()
    def setMessageHandler(self, handler):
        '''void QXmlSchema.setMessageHandler(QAbstractMessageHandler handler)'''
    def documentUri(self):
        '''QUrl QXmlSchema.documentUri()'''
        return QUrl()
    def namePool(self):
        '''QXmlNamePool QXmlSchema.namePool()'''
        return QXmlNamePool()
    def isValid(self):
        '''bool QXmlSchema.isValid()'''
        return bool()
    def load(self, source):
        '''bool QXmlSchema.load(QUrl source)'''
        return bool()
    def load(self, source, documentUri = QUrl()):
        '''bool QXmlSchema.load(QIODevice source, QUrl documentUri = QUrl())'''
        return bool()
    def load(self, data, documentUri = QUrl()):
        '''bool QXmlSchema.load(QByteArray data, QUrl documentUri = QUrl())'''
        return bool()


class QXmlSchemaValidator():
    """"""
    def __init__(self):
        '''void QXmlSchemaValidator.__init__()'''
    def __init__(self, schema):
        '''void QXmlSchemaValidator.__init__(QXmlSchema schema)'''
    def networkAccessManager(self):
        '''QNetworkAccessManager QXmlSchemaValidator.networkAccessManager()'''
        return QNetworkAccessManager()
    def setNetworkAccessManager(self, networkmanager):
        '''void QXmlSchemaValidator.setNetworkAccessManager(QNetworkAccessManager networkmanager)'''
    def uriResolver(self):
        '''QAbstractUriResolver QXmlSchemaValidator.uriResolver()'''
        return QAbstractUriResolver()
    def setUriResolver(self, resolver):
        '''void QXmlSchemaValidator.setUriResolver(QAbstractUriResolver resolver)'''
    def messageHandler(self):
        '''QAbstractMessageHandler QXmlSchemaValidator.messageHandler()'''
        return QAbstractMessageHandler()
    def setMessageHandler(self, handler):
        '''void QXmlSchemaValidator.setMessageHandler(QAbstractMessageHandler handler)'''
    def schema(self):
        '''QXmlSchema QXmlSchemaValidator.schema()'''
        return QXmlSchema()
    def namePool(self):
        '''QXmlNamePool QXmlSchemaValidator.namePool()'''
        return QXmlNamePool()
    def validate(self, source):
        '''bool QXmlSchemaValidator.validate(QUrl source)'''
        return bool()
    def validate(self, source, documentUri = QUrl()):
        '''bool QXmlSchemaValidator.validate(QIODevice source, QUrl documentUri = QUrl())'''
        return bool()
    def validate(self, data, documentUri = QUrl()):
        '''bool QXmlSchemaValidator.validate(QByteArray data, QUrl documentUri = QUrl())'''
        return bool()
    def setSchema(self, schema):
        '''void QXmlSchemaValidator.setSchema(QXmlSchema schema)'''





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QVideoWidget(QWidget, QMediaBindableInterface):
    """"""
    def __init__(self, parent = None):
        '''void QVideoWidget.__init__(QWidget parent = None)'''
    def setMediaObject(self, object):
        '''bool QVideoWidget.setMediaObject(QMediaObject object)'''
        return bool()
    def paintEvent(self, event):
        '''void QVideoWidget.paintEvent(QPaintEvent event)'''
    def moveEvent(self, event):
        '''void QVideoWidget.moveEvent(QMoveEvent event)'''
    def resizeEvent(self, event):
        '''void QVideoWidget.resizeEvent(QResizeEvent event)'''
    def hideEvent(self, event):
        '''void QVideoWidget.hideEvent(QHideEvent event)'''
    def showEvent(self, event):
        '''void QVideoWidget.showEvent(QShowEvent event)'''
    def event(self, event):
        '''bool QVideoWidget.event(QEvent event)'''
        return bool()
    saturationChanged = pyqtSignal() # void saturationChanged(int) - signal
    hueChanged = pyqtSignal() # void hueChanged(int) - signal
    contrastChanged = pyqtSignal() # void contrastChanged(int) - signal
    brightnessChanged = pyqtSignal() # void brightnessChanged(int) - signal
    fullScreenChanged = pyqtSignal() # void fullScreenChanged(bool) - signal
    def setSaturation(self, saturation):
        '''void QVideoWidget.setSaturation(int saturation)'''
    def setHue(self, hue):
        '''void QVideoWidget.setHue(int hue)'''
    def setContrast(self, contrast):
        '''void QVideoWidget.setContrast(int contrast)'''
    def setBrightness(self, brightness):
        '''void QVideoWidget.setBrightness(int brightness)'''
    def setAspectRatioMode(self, mode):
        '''void QVideoWidget.setAspectRatioMode(Qt.AspectRatioMode mode)'''
    def setFullScreen(self, fullScreen):
        '''void QVideoWidget.setFullScreen(bool fullScreen)'''
    def sizeHint(self):
        '''QSize QVideoWidget.sizeHint()'''
        return QSize()
    def saturation(self):
        '''int QVideoWidget.saturation()'''
        return int()
    def hue(self):
        '''int QVideoWidget.hue()'''
        return int()
    def contrast(self):
        '''int QVideoWidget.contrast()'''
        return int()
    def brightness(self):
        '''int QVideoWidget.brightness()'''
        return int()
    def aspectRatioMode(self):
        '''Qt.AspectRatioMode QVideoWidget.aspectRatioMode()'''
        return Qt.AspectRatioMode()
    def mediaObject(self):
        '''QMediaObject QVideoWidget.mediaObject()'''
        return QMediaObject()


class QCameraViewfinder(QVideoWidget):
    """"""
    def __init__(self, parent = None):
        '''void QCameraViewfinder.__init__(QWidget parent = None)'''
    def setMediaObject(self, object):
        '''bool QCameraViewfinder.setMediaObject(QMediaObject object)'''
        return bool()
    def mediaObject(self):
        '''QMediaObject QCameraViewfinder.mediaObject()'''
        return QMediaObject()


class QGraphicsVideoItem(QGraphicsObject, QMediaBindableInterface):
    """"""
    def __init__(self, parent = None):
        '''void QGraphicsVideoItem.__init__(QGraphicsItem parent = None)'''
    def setMediaObject(self, object):
        '''bool QGraphicsVideoItem.setMediaObject(QMediaObject object)'''
        return bool()
    def itemChange(self, change, value):
        '''QVariant QGraphicsVideoItem.itemChange(QGraphicsItem.GraphicsItemChange change, QVariant value)'''
        return QVariant()
    def timerEvent(self, event):
        '''void QGraphicsVideoItem.timerEvent(QTimerEvent event)'''
    nativeSizeChanged = pyqtSignal() # void nativeSizeChanged(const QSizeFamp;) - signal
    def paint(self, painter, option, widget = None):
        '''void QGraphicsVideoItem.paint(QPainter painter, QStyleOptionGraphicsItem option, QWidget widget = None)'''
    def boundingRect(self):
        '''QRectF QGraphicsVideoItem.boundingRect()'''
        return QRectF()
    def nativeSize(self):
        '''QSizeF QGraphicsVideoItem.nativeSize()'''
        return QSizeF()
    def setSize(self, size):
        '''void QGraphicsVideoItem.setSize(QSizeF size)'''
    def size(self):
        '''QSizeF QGraphicsVideoItem.size()'''
        return QSizeF()
    def setOffset(self, offset):
        '''void QGraphicsVideoItem.setOffset(QPointF offset)'''
    def offset(self):
        '''QPointF QGraphicsVideoItem.offset()'''
        return QPointF()
    def setAspectRatioMode(self, mode):
        '''void QGraphicsVideoItem.setAspectRatioMode(Qt.AspectRatioMode mode)'''
    def aspectRatioMode(self):
        '''Qt.AspectRatioMode QGraphicsVideoItem.aspectRatioMode()'''
        return Qt.AspectRatioMode()
    def mediaObject(self):
        '''QMediaObject QGraphicsVideoItem.mediaObject()'''
        return QMediaObject()





#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Standard errno system symbols.


This module makes available standard ``errno`` system symbols. The value of each
symbol is the corresponding integer value. The names and descriptions are
borrowed from :file:`linux/include/errno.h`, which should be pretty
all-inclusive.


"""
"""
Dictionary providing a mapping from the errno value to the string name in the
underlying system.  For instance, ``errno.errorcode[errno.EPERM]`` maps to
``'EPERM'``.

To translate a numeric error code to an error message, use :func:`os.strerror`.

Of the following list, symbols that are not used on the current platform are not
defined by the module.  The specific list of defined symbols is available as
``errno.errorcode.keys()``.  Symbols available can include:


"""
errorcode = None
"""
Operation not permitted


"""
EPERM = None
"""
No such file or directory


"""
ENOENT = None
"""
No such process


"""
ESRCH = None
"""
Interrupted system call


"""
EINTR = None
"""
I/O error


"""
EIO = None
"""
No such device or address


"""
ENXIO = None
"""
Arg list too long


"""
E2BIG = None
"""
Exec format error


"""
ENOEXEC = None
"""
Bad file number


"""
EBADF = None
"""
No child processes


"""
ECHILD = None
"""
Try again


"""
EAGAIN = None
"""
Out of memory


"""
ENOMEM = None
"""
Permission denied


"""
EACCES = None
"""
Bad address


"""
EFAULT = None
"""
Block device required


"""
ENOTBLK = None
"""
Device or resource busy


"""
EBUSY = None
"""
File exists


"""
EEXIST = None
"""
Cross-device link


"""
EXDEV = None
"""
No such device


"""
ENODEV = None
"""
Not a directory


"""
ENOTDIR = None
"""
Is a directory


"""
EISDIR = None
"""
Invalid argument


"""
EINVAL = None
"""
File table overflow


"""
ENFILE = None
"""
Too many open files


"""
EMFILE = None
"""
Not a typewriter


"""
ENOTTY = None
"""
Text file busy


"""
ETXTBSY = None
"""
File too large


"""
EFBIG = None
"""
No space left on device


"""
ENOSPC = None
"""
Illegal seek


"""
ESPIPE = None
"""
Read-only file system


"""
EROFS = None
"""
Too many links


"""
EMLINK = None
"""
Broken pipe


"""
EPIPE = None
"""
Math argument out of domain of func


"""
EDOM = None
"""
Math result not representable


"""
ERANGE = None
"""
Resource deadlock would occur


"""
EDEADLK = None
"""
File name too long


"""
ENAMETOOLONG = None
"""
No record locks available


"""
ENOLCK = None
"""
Function not implemented


"""
ENOSYS = None
"""
Directory not empty


"""
ENOTEMPTY = None
"""
Too many symbolic links encountered


"""
ELOOP = None
"""
Operation would block


"""
EWOULDBLOCK = None
"""
No message of desired type


"""
ENOMSG = None
"""
Identifier removed


"""
EIDRM = None
"""
Channel number out of range


"""
ECHRNG = None
"""
Level 2 not synchronized


"""
EL2NSYNC = None
"""
Level 3 halted


"""
EL3HLT = None
"""
Level 3 reset


"""
EL3RST = None
"""
Link number out of range


"""
ELNRNG = None
"""
Protocol driver not attached


"""
EUNATCH = None
"""
No CSI structure available


"""
ENOCSI = None
"""
Level 2 halted


"""
EL2HLT = None
"""
Invalid exchange


"""
EBADE = None
"""
Invalid request descriptor


"""
EBADR = None
"""
Exchange full


"""
EXFULL = None
"""
No anode


"""
ENOANO = None
"""
Invalid request code


"""
EBADRQC = None
"""
Invalid slot


"""
EBADSLT = None
"""
File locking deadlock error


"""
EDEADLOCK = None
"""
Bad font file format


"""
EBFONT = None
"""
Device not a stream


"""
ENOSTR = None
"""
No data available


"""
ENODATA = None
"""
Timer expired


"""
ETIME = None
"""
Out of streams resources


"""
ENOSR = None
"""
Machine is not on the network


"""
ENONET = None
"""
Package not installed


"""
ENOPKG = None
"""
Object is remote


"""
EREMOTE = None
"""
Link has been severed


"""
ENOLINK = None
"""
Advertise error


"""
EADV = None
"""
Srmount error


"""
ESRMNT = None
"""
Communication error on send


"""
ECOMM = None
"""
Protocol error


"""
EPROTO = None
"""
Multihop attempted


"""
EMULTIHOP = None
"""
RFS specific error


"""
EDOTDOT = None
"""
Not a data message


"""
EBADMSG = None
"""
Value too large for defined data type


"""
EOVERFLOW = None
"""
Name not unique on network


"""
ENOTUNIQ = None
"""
File descriptor in bad state


"""
EBADFD = None
"""
Remote address changed


"""
EREMCHG = None
"""
Can not access a needed shared library


"""
ELIBACC = None
"""
Accessing a corrupted shared library


"""
ELIBBAD = None
"""
.lib section in a.out corrupted


"""
ELIBSCN = None
"""
Attempting to link in too many shared libraries


"""
ELIBMAX = None
"""
Cannot exec a shared library directly


"""
ELIBEXEC = None
"""
Illegal byte sequence


"""
EILSEQ = None
"""
Interrupted system call should be restarted


"""
ERESTART = None
"""
Streams pipe error


"""
ESTRPIPE = None
"""
Too many users


"""
EUSERS = None
"""
Socket operation on non-socket


"""
ENOTSOCK = None
"""
Destination address required


"""
EDESTADDRREQ = None
"""
Message too long


"""
EMSGSIZE = None
"""
Protocol wrong type for socket


"""
EPROTOTYPE = None
"""
Protocol not available


"""
ENOPROTOOPT = None
"""
Protocol not supported


"""
EPROTONOSUPPORT = None
"""
Socket type not supported


"""
ESOCKTNOSUPPORT = None
"""
Operation not supported on transport endpoint


"""
EOPNOTSUPP = None
"""
Protocol family not supported


"""
EPFNOSUPPORT = None
"""
Address family not supported by protocol


"""
EAFNOSUPPORT = None
"""
Address already in use


"""
EADDRINUSE = None
"""
Cannot assign requested address


"""
EADDRNOTAVAIL = None
"""
Network is down


"""
ENETDOWN = None
"""
Network is unreachable


"""
ENETUNREACH = None
"""
Network dropped connection because of reset


"""
ENETRESET = None
"""
Software caused connection abort


"""
ECONNABORTED = None
"""
Connection reset by peer


"""
ECONNRESET = None
"""
No buffer space available


"""
ENOBUFS = None
"""
Transport endpoint is already connected


"""
EISCONN = None
"""
Transport endpoint is not connected


"""
ENOTCONN = None
"""
Cannot send after transport endpoint shutdown


"""
ESHUTDOWN = None
"""
Too many references: cannot splice


"""
ETOOMANYREFS = None
"""
Connection timed out


"""
ETIMEDOUT = None
"""
Connection refused


"""
ECONNREFUSED = None
"""
Host is down


"""
EHOSTDOWN = None
"""
No route to host


"""
EHOSTUNREACH = None
"""
Operation already in progress


"""
EALREADY = None
"""
Operation now in progress


"""
EINPROGRESS = None
"""
Stale NFS file handle


"""
ESTALE = None
"""
Structure needs cleaning


"""
EUCLEAN = None
"""
Not a XENIX named type file


"""
ENOTNAM = None
"""
No XENIX semaphores available


"""
ENAVAIL = None
"""
Is a named type file


"""
EISNAM = None
"""
Remote I/O error


"""
EREMOTEIO = None



# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module is always available. It provides access to mathematical
functions for complex numbers. """

__package__ = None

def acos(x):
  """ acos(x)
  
  Return the arc cosine of x. """
  pass

def acosh(x):
  """ acosh(x)
  
  Return the hyperbolic arccosine of x. """
  pass

def asin(x):
  """ asin(x)
  
  Return the arc sine of x. """
  pass

def asinh(x):
  """ asinh(x)
  
  Return the hyperbolic arc sine of x. """
  pass

def atan(x):
  """ atan(x)
  
  Return the arc tangent of x. """
  pass

def atanh(x):
  """ atanh(x)
  
  Return the hyperbolic arc tangent of x. """
  pass

def cos(x):
  """ cos(x)
  
  Return the cosine of x. """
  pass

def cosh(x):
  """ cosh(x)
  
  Return the hyperbolic cosine of x. """
  pass

e = 2.71828182846

def exp(x):
  """ exp(x)
  
  Return the exponential value e**x. """
  pass

def isinf(z):
  """ isinf(z) -> bool
  Checks if the real or imaginary part of z is infinite. """
  return None

def isnan(z):
  """ isnan(z) -> bool
  Checks if the real or imaginary part of z not a number (NaN) """
  return None

def log(x, base=None):
  """ log(x[, base]) -> the logarithm of x to the given base.
  If the base not specified, returns the natural logarithm (base e) of x. """
  return None

def log10(x):
  """ log10(x)
  
  Return the base-10 logarithm of x. """
  pass

def phase(z):
  """ phase(z) -> float
  
  Return argument, also known as the phase angle, of a complex. """
  return 1.0

pi = 3.14159265359

def polar(z):
  """ polar(z) -> r: float, phi: float
  
  Convert a complex from rectangular coordinates to polar coordinates. r is
  the distance from 0 and phi the phase angle. """
  return 1.0

def rect(r, phi):
  """ rect(r, phi) -> z: complex
  
  Convert from polar coordinates to rectangular coordinates. """
  return None

def sin(x):
  """ sin(x)
  
  Return the sine of x. """
  pass

def sinh(x):
  """ sinh(x)
  
  Return the hyperbolic sine of x. """
  pass

def sqrt(x):
  """ sqrt(x)
  
  Return the square root of x. """
  pass

def tan(x):
  """ tan(x)
  
  Return the tangent of x. """
  pass

def tanh(x):
  """ tanh(x)
  
  Return the hyperbolic tangent of x. """
  pass




# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module performs file control and I/O control on file 
descriptors.  It is an interface to the fcntl() and ioctl() Unix
routines.  File descriptors can be obtained with the fileno() method of
a file or socket object. """

DN_ACCESS = 1
DN_ATTRIB = 32
DN_CREATE = 4
DN_DELETE = 8
DN_MODIFY = 2
DN_MULTISHOT = 2147483648
DN_RENAME = 16
FASYNC = 8192
FD_CLOEXEC = 1
F_DUPFD = 0
F_EXLCK = 4
F_GETFD = 1
F_GETFL = 3
F_GETLEASE = 1025
F_GETLK = 5
F_GETLK64 = 5
F_GETOWN = 9
F_GETSIG = 11
F_NOTIFY = 1026
F_RDLCK = 0
F_SETFD = 2
F_SETFL = 4
F_SETLEASE = 1024
F_SETLK = 6
F_SETLK64 = 6
F_SETLKW = 7
F_SETLKW64 = 7
F_SETOWN = 8
F_SETSIG = 10
F_SHLCK = 8
F_UNLCK = 2
F_WRLCK = 1
I_ATMARK = 21279
I_CANPUT = 21282
I_CKBAND = 21277
I_FDINSERT = 21264
I_FIND = 21259
I_FLUSH = 21253
I_FLUSHBAND = 21276
I_GETBAND = 21278
I_GETCLTIME = 21281
I_GETSIG = 21258
I_GRDOPT = 21255
I_GWROPT = 21268
I_LINK = 21260
I_LIST = 21269
I_LOOK = 21252
I_NREAD = 21249
I_PEEK = 21263
I_PLINK = 21270
I_POP = 21251
I_PUNLINK = 21271
I_PUSH = 21250
I_RECVFD = 21262
I_SENDFD = 21265
I_SETCLTIME = 21280
I_SETSIG = 21257
I_SRDOPT = 21254
I_STR = 21256
I_SWROPT = 21267
I_UNLINK = 21261
LOCK_EX = 2
LOCK_MAND = 32
LOCK_NB = 4
LOCK_READ = 64
LOCK_RW = 192
LOCK_SH = 1
LOCK_UN = 8
LOCK_WRITE = 128
__package__ = None

def fcntl(fd, opt, arg=None):
  """ fcntl(fd, opt, [arg])
  
  Perform the requested operation on file descriptor fd.  The operation
  is defined by op and is operating system dependent.  These constants are
  available from the fcntl module.  The argument arg is optional, and
  defaults to 0; it may be an int or a string.  If arg is given as a string,
  the return value of fcntl is a string of that length, containing the
  resulting value put in the arg buffer by the operating system.  The length
  of the arg string is not allowed to exceed 1024 bytes.  If the arg given
  is an integer or if none is specified, the result value is an integer
  corresponding to the return value of the fcntl call in the C code. """
  pass

def flock(fd, operation):
  """ flock(fd, operation)
  
  Perform the lock operation op on file descriptor fd.  See the Unix 
  manual page for flock(3) for details.  (On some systems, this function is
  emulated using fcntl().) """
  pass

def ioctl(fd, opt, arg=None, mutate_flag=None):
  """ ioctl(fd, opt[, arg[, mutate_flag]])
  
  Perform the requested operation on file descriptor fd.  The operation is
  defined by opt and is operating system dependent.  Typically these codes are
  retrieved from the fcntl or termios library modules.
  
  The argument arg is optional, and defaults to 0; it may be an int or a
  buffer containing character data (most likely a string or an array). 
  
  If the argument is a mutable buffer (such as an array) and if the
  mutate_flag argument (which is only allowed in this case) is true then the
  buffer is (in effect) passed to the operating system and changes made by
  the OS will be reflected in the contents of the buffer after the call has
  returned.  The return value is the integer returned by the ioctl system
  call.
  
  If the argument is a mutable buffer and the mutable_flag argument is not
  passed or is false, the behavior is as if a string had been passed.  This
  behavior will change in future releases of Python.
  
  If the argument is an immutable buffer (most likely a string) then a copy
  of the buffer is passed to the operating system and the return value is a
  string of the same length containing whatever the operating system put in
  the buffer.  The length of the arg buffer in this case is not allowed to
  exceed 1024 bytes.
  
  If the arg given is an integer or if none is specified, the result value is
  an integer corresponding to the return value of the ioctl call in the C
  code. """
  pass

def lockf():
  """ lockf (fd, operation, length=0, start=0, whence=0)
  
  This is essentially a wrapper around the fcntl() locking calls.  fd is the
  file descriptor of the file to lock or unlock, and operation is one of the
  following values:
  
      LOCK_UN - unlock
      LOCK_SH - acquire a shared lock
      LOCK_EX - acquire an exclusive lock
  
  When operation is LOCK_SH or LOCK_EX, it can also be bitwise ORed with
  LOCK_NB to avoid blocking on lock acquisition.  If LOCK_NB is used and the
  lock cannot be acquired, an IOError will be raised and the exception will
  have an errno attribute set to EACCES or EAGAIN (depending on the operating
  system -- for portability, check for either value).
  
  length is the number of bytes to lock, with the default meaning to lock to
  EOF.  start is the byte offset, relative to whence, to that the lock
  starts.  whence is as with fileobj.seek(), specifically:
  
      0 - relative to the start of the file (SEEK_SET)
      1 - relative to the current buffer position (SEEK_CUR)
      2 - relative to the end of the file (SEEK_END) """
  pass




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QScriptClass():
    """"""
    # Enum QScriptClass.Extension
    Callable = 0
    HasInstance = 0

    # Enum QScriptClass.QueryFlag
    HandlesReadAccess = 0
    HandlesWriteAccess = 0

    def __init__(self, engine):
        '''void QScriptClass.__init__(QScriptEngine engine)'''
    def extension(self, extension, argument = QVariant()):
        '''QVariant QScriptClass.extension(QScriptClass.Extension extension, QVariant argument = QVariant())'''
        return QVariant()
    def supportsExtension(self, extension):
        '''bool QScriptClass.supportsExtension(QScriptClass.Extension extension)'''
        return bool()
    def name(self):
        '''QString QScriptClass.name()'''
        return QString()
    def prototype(self):
        '''QScriptValue QScriptClass.prototype()'''
        return QScriptValue()
    def newIterator(self, object):
        '''QScriptClassPropertyIterator QScriptClass.newIterator(QScriptValue object)'''
        return QScriptClassPropertyIterator()
    def propertyFlags(self, object, name, id):
        '''QScriptValue.PropertyFlags QScriptClass.propertyFlags(QScriptValue object, QScriptString name, int id)'''
        return QScriptValue.PropertyFlags()
    def setProperty(self, object, name, id, value):
        '''void QScriptClass.setProperty(QScriptValue object, QScriptString name, int id, QScriptValue value)'''
    def property(self, object, name, id):
        '''QScriptValue QScriptClass.property(QScriptValue object, QScriptString name, int id)'''
        return QScriptValue()
    def queryProperty(self, object, name, flags, id):
        '''QScriptClass.QueryFlags QScriptClass.queryProperty(QScriptValue object, QScriptString name, QScriptClass.QueryFlags flags, int id)'''
        return QScriptClass.QueryFlags()
    def engine(self):
        '''QScriptEngine QScriptClass.engine()'''
        return QScriptEngine()
    class QueryFlags():
        """"""
        def __init__(self):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__init__()'''
            return QScriptClass.QueryFlags()
        def __init__(self):
            '''int QScriptClass.QueryFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QScriptClass.QueryFlags.__init__()'''
        def __bool__(self):
            '''int QScriptClass.QueryFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QScriptClass.QueryFlags.__ne__(QScriptClass.QueryFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QScriptClass.QueryFlags.__eq__(QScriptClass.QueryFlags f)'''
            return bool()
        def __invert__(self):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__invert__()'''
            return QScriptClass.QueryFlags()
        def __and__(self, mask):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__and__(int mask)'''
            return QScriptClass.QueryFlags()
        def __xor__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__xor__(QScriptClass.QueryFlags f)'''
            return QScriptClass.QueryFlags()
        def __xor__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__xor__(int f)'''
            return QScriptClass.QueryFlags()
        def __or__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__or__(QScriptClass.QueryFlags f)'''
            return QScriptClass.QueryFlags()
        def __or__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__or__(int f)'''
            return QScriptClass.QueryFlags()
        def __int__(self):
            '''int QScriptClass.QueryFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__ixor__(QScriptClass.QueryFlags f)'''
            return QScriptClass.QueryFlags()
        def __ior__(self, f):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__ior__(QScriptClass.QueryFlags f)'''
            return QScriptClass.QueryFlags()
        def __iand__(self, mask):
            '''QScriptClass.QueryFlags QScriptClass.QueryFlags.__iand__(int mask)'''
            return QScriptClass.QueryFlags()


class QScriptClassPropertyIterator():
    """"""
    def __init__(self, object):
        '''void QScriptClassPropertyIterator.__init__(QScriptValue object)'''
    def flags(self):
        '''QScriptValue.PropertyFlags QScriptClassPropertyIterator.flags()'''
        return QScriptValue.PropertyFlags()
    def id(self):
        '''int QScriptClassPropertyIterator.id()'''
        return int()
    def name(self):
        '''abstract QScriptString QScriptClassPropertyIterator.name()'''
        return QScriptString()
    def toBack(self):
        '''abstract void QScriptClassPropertyIterator.toBack()'''
    def toFront(self):
        '''abstract void QScriptClassPropertyIterator.toFront()'''
    def previous(self):
        '''abstract void QScriptClassPropertyIterator.previous()'''
    def hasPrevious(self):
        '''abstract bool QScriptClassPropertyIterator.hasPrevious()'''
        return bool()
    def next(self):
        '''abstract void QScriptClassPropertyIterator.next()'''
    def hasNext(self):
        '''abstract bool QScriptClassPropertyIterator.hasNext()'''
        return bool()
    def object(self):
        '''QScriptValue QScriptClassPropertyIterator.object()'''
        return QScriptValue()


class QScriptContext():
    """"""
    # Enum QScriptContext.Error
    UnknownError = 0
    ReferenceError = 0
    SyntaxError = 0
    TypeError = 0
    RangeError = 0
    URIError = 0

    # Enum QScriptContext.ExecutionState
    NormalState = 0
    ExceptionState = 0

    def toString(self):
        '''QString QScriptContext.toString()'''
        return QString()
    def throwError(self, error, text):
        '''QScriptValue QScriptContext.throwError(QScriptContext.Error error, QString text)'''
        return QScriptValue()
    def throwError(self, text):
        '''QScriptValue QScriptContext.throwError(QString text)'''
        return QScriptValue()
    def throwValue(self, value):
        '''QScriptValue QScriptContext.throwValue(QScriptValue value)'''
        return QScriptValue()
    def backtrace(self):
        '''QStringList QScriptContext.backtrace()'''
        return QStringList()
    def isCalledAsConstructor(self):
        '''bool QScriptContext.isCalledAsConstructor()'''
        return bool()
    def setThisObject(self, thisObject):
        '''void QScriptContext.setThisObject(QScriptValue thisObject)'''
    def thisObject(self):
        '''QScriptValue QScriptContext.thisObject()'''
        return QScriptValue()
    def setActivationObject(self, activation):
        '''void QScriptContext.setActivationObject(QScriptValue activation)'''
    def activationObject(self):
        '''QScriptValue QScriptContext.activationObject()'''
        return QScriptValue()
    def argumentsObject(self):
        '''QScriptValue QScriptContext.argumentsObject()'''
        return QScriptValue()
    def argument(self, index):
        '''QScriptValue QScriptContext.argument(int index)'''
        return QScriptValue()
    def argumentCount(self):
        '''int QScriptContext.argumentCount()'''
        return int()
    def callee(self):
        '''QScriptValue QScriptContext.callee()'''
        return QScriptValue()
    def state(self):
        '''QScriptContext.ExecutionState QScriptContext.state()'''
        return QScriptContext.ExecutionState()
    def engine(self):
        '''QScriptEngine QScriptContext.engine()'''
        return QScriptEngine()
    def parentContext(self):
        '''QScriptContext QScriptContext.parentContext()'''
        return QScriptContext()


class QScriptContextInfo():
    """"""
    # Enum QScriptContextInfo.FunctionType
    ScriptFunction = 0
    QtFunction = 0
    QtPropertyFunction = 0
    NativeFunction = 0

    def __init__(self, context):
        '''void QScriptContextInfo.__init__(QScriptContext context)'''
    def __init__(self, other):
        '''void QScriptContextInfo.__init__(QScriptContextInfo other)'''
    def __init__(self):
        '''void QScriptContextInfo.__init__()'''
    def __ne__(self, other):
        '''bool QScriptContextInfo.__ne__(QScriptContextInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QScriptContextInfo.__eq__(QScriptContextInfo other)'''
        return bool()
    def functionMetaIndex(self):
        '''int QScriptContextInfo.functionMetaIndex()'''
        return int()
    def functionEndLineNumber(self):
        '''int QScriptContextInfo.functionEndLineNumber()'''
        return int()
    def functionStartLineNumber(self):
        '''int QScriptContextInfo.functionStartLineNumber()'''
        return int()
    def functionParameterNames(self):
        '''QStringList QScriptContextInfo.functionParameterNames()'''
        return QStringList()
    def functionType(self):
        '''QScriptContextInfo.FunctionType QScriptContextInfo.functionType()'''
        return QScriptContextInfo.FunctionType()
    def functionName(self):
        '''QString QScriptContextInfo.functionName()'''
        return QString()
    def columnNumber(self):
        '''int QScriptContextInfo.columnNumber()'''
        return int()
    def lineNumber(self):
        '''int QScriptContextInfo.lineNumber()'''
        return int()
    def fileName(self):
        '''QString QScriptContextInfo.fileName()'''
        return QString()
    def scriptId(self):
        '''int QScriptContextInfo.scriptId()'''
        return int()
    def isNull(self):
        '''bool QScriptContextInfo.isNull()'''
        return bool()


class QScriptEngine(QObject):
    """"""
    # Enum QScriptEngine.QObjectWrapOption
    ExcludeChildObjects = 0
    ExcludeSuperClassMethods = 0
    ExcludeSuperClassProperties = 0
    AutoCreateDynamicProperties = 0
    SkipMethodsInEnumeration = 0
    PreferExistingWrapperObject = 0
    ExcludeSuperClassContents = 0
    ExcludeDeleteLater = 0
    ExcludeSlots = 0

    # Enum QScriptEngine.ValueOwnership
    QtOwnership = 0
    ScriptOwnership = 0
    AutoOwnership = 0

    def __init__(self):
        '''void QScriptEngine.__init__()'''
    def __init__(self, parent):
        '''void QScriptEngine.__init__(QObject parent)'''
    def reportAdditionalMemoryCost(self, size):
        '''void QScriptEngine.reportAdditionalMemoryCost(int size)'''
    signalHandlerException = pyqtSignal() # void signalHandlerException(const QScriptValueamp;) - signal
    def toObject(self, value):
        '''QScriptValue QScriptEngine.toObject(QScriptValue value)'''
        return QScriptValue()
    def installTranslatorFunctions(self, object = QScriptValue()):
        '''void QScriptEngine.installTranslatorFunctions(QScriptValue object = QScriptValue())'''
    def checkSyntax(self, program):
        '''static QScriptSyntaxCheckResult QScriptEngine.checkSyntax(QString program)'''
        return QScriptSyntaxCheckResult()
    def setGlobalObject(self, object):
        '''void QScriptEngine.setGlobalObject(QScriptValue object)'''
    def toStringHandle(self, str):
        '''QScriptString QScriptEngine.toStringHandle(QString str)'''
        return QScriptString()
    def agent(self):
        '''QScriptEngineAgent QScriptEngine.agent()'''
        return QScriptEngineAgent()
    def setAgent(self, agent):
        '''void QScriptEngine.setAgent(QScriptEngineAgent agent)'''
    def importedExtensions(self):
        '''QStringList QScriptEngine.importedExtensions()'''
        return QStringList()
    def availableExtensions(self):
        '''QStringList QScriptEngine.availableExtensions()'''
        return QStringList()
    def clearExceptions(self):
        '''void QScriptEngine.clearExceptions()'''
    def abortEvaluation(self, result = QScriptValue()):
        '''void QScriptEngine.abortEvaluation(QScriptValue result = QScriptValue())'''
    def isEvaluating(self):
        '''bool QScriptEngine.isEvaluating()'''
        return bool()
    def processEventsInterval(self):
        '''int QScriptEngine.processEventsInterval()'''
        return int()
    def setProcessEventsInterval(self, interval):
        '''void QScriptEngine.setProcessEventsInterval(int interval)'''
    def collectGarbage(self):
        '''void QScriptEngine.collectGarbage()'''
    def importExtension(self, extension):
        '''QScriptValue QScriptEngine.importExtension(QString extension)'''
        return QScriptValue()
    def setDefaultPrototype(self, metaTypeId, prototype):
        '''void QScriptEngine.setDefaultPrototype(int metaTypeId, QScriptValue prototype)'''
    def defaultPrototype(self, metaTypeId):
        '''QScriptValue QScriptEngine.defaultPrototype(int metaTypeId)'''
        return QScriptValue()
    def newQMetaObject(self, metaObject, ctor = QScriptValue()):
        '''QScriptValue QScriptEngine.newQMetaObject(QMetaObject metaObject, QScriptValue ctor = QScriptValue())'''
        return QScriptValue()
    def newQObject(self, object, ownership = None, options = 0):
        '''QScriptValue QScriptEngine.newQObject(QObject object, QScriptEngine.ValueOwnership ownership = QScriptEngine.QtOwnership, QScriptEngine.QObjectWrapOptions options = 0)'''
        return QScriptValue()
    def newQObject(self, scriptObject, qtObject, ownership = None, options = 0):
        '''QScriptValue QScriptEngine.newQObject(QScriptValue scriptObject, QObject qtObject, QScriptEngine.ValueOwnership ownership = QScriptEngine.QtOwnership, QScriptEngine.QObjectWrapOptions options = 0)'''
        return QScriptValue()
    def newDate(self, value):
        '''QScriptValue QScriptEngine.newDate(float value)'''
        return QScriptValue()
    def newDate(self, value):
        '''QScriptValue QScriptEngine.newDate(QDateTime value)'''
        return QScriptValue()
    def newArray(self, length = 0):
        '''QScriptValue QScriptEngine.newArray(int length = 0)'''
        return QScriptValue()
    def newObject(self):
        '''QScriptValue QScriptEngine.newObject()'''
        return QScriptValue()
    def newObject(self, scriptClass, data = QScriptValue()):
        '''QScriptValue QScriptEngine.newObject(QScriptClass scriptClass, QScriptValue data = QScriptValue())'''
        return QScriptValue()
    def newRegExp(self, regexp):
        '''QScriptValue QScriptEngine.newRegExp(QRegExp regexp)'''
        return QScriptValue()
    def newRegExp(self, pattern, flags):
        '''QScriptValue QScriptEngine.newRegExp(QString pattern, QString flags)'''
        return QScriptValue()
    def newVariant(self, value):
        '''QScriptValue QScriptEngine.newVariant(QVariant value)'''
        return QScriptValue()
    def newVariant(self, object, value):
        '''QScriptValue QScriptEngine.newVariant(QScriptValue object, QVariant value)'''
        return QScriptValue()
    def newFunction(self, signature, length = 0):
        '''QScriptValue QScriptEngine.newFunction(callable signature, int length = 0)'''
        return QScriptValue()
    def newFunction(self, signature, prototype, length = 0):
        '''QScriptValue QScriptEngine.newFunction(callable signature, QScriptValue prototype, int length = 0)'''
        return QScriptValue()
    def undefinedValue(self):
        '''QScriptValue QScriptEngine.undefinedValue()'''
        return QScriptValue()
    def nullValue(self):
        '''QScriptValue QScriptEngine.nullValue()'''
        return QScriptValue()
    def uncaughtExceptionLineNumber(self):
        '''int QScriptEngine.uncaughtExceptionLineNumber()'''
        return int()
    def uncaughtException(self):
        '''QScriptValue QScriptEngine.uncaughtException()'''
        return QScriptValue()
    def uncaughtExceptionBacktrace(self):
        '''QStringList QScriptEngine.uncaughtExceptionBacktrace()'''
        return QStringList()
    def hasUncaughtException(self):
        '''bool QScriptEngine.hasUncaughtException()'''
        return bool()
    def evaluate(self, program, fileName = QString(), lineNumber = 1):
        '''QScriptValue QScriptEngine.evaluate(QString program, QString fileName = QString(), int lineNumber = 1)'''
        return QScriptValue()
    def canEvaluate(self, program):
        '''bool QScriptEngine.canEvaluate(QString program)'''
        return bool()
    def popContext(self):
        '''void QScriptEngine.popContext()'''
    def pushContext(self):
        '''QScriptContext QScriptEngine.pushContext()'''
        return QScriptContext()
    def currentContext(self):
        '''QScriptContext QScriptEngine.currentContext()'''
        return QScriptContext()
    def globalObject(self):
        '''QScriptValue QScriptEngine.globalObject()'''
        return QScriptValue()
    class QObjectWrapOptions():
        """"""
        def __init__(self):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__init__()'''
            return QScriptEngine.QObjectWrapOptions()
        def __init__(self):
            '''int QScriptEngine.QObjectWrapOptions.__init__()'''
            return int()
        def __init__(self):
            '''void QScriptEngine.QObjectWrapOptions.__init__()'''
        def __bool__(self):
            '''int QScriptEngine.QObjectWrapOptions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QScriptEngine.QObjectWrapOptions.__ne__(QScriptEngine.QObjectWrapOptions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QScriptEngine.QObjectWrapOptions.__eq__(QScriptEngine.QObjectWrapOptions f)'''
            return bool()
        def __invert__(self):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__invert__()'''
            return QScriptEngine.QObjectWrapOptions()
        def __and__(self, mask):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__and__(int mask)'''
            return QScriptEngine.QObjectWrapOptions()
        def __xor__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__xor__(QScriptEngine.QObjectWrapOptions f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __xor__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__xor__(int f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __or__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__or__(QScriptEngine.QObjectWrapOptions f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __or__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__or__(int f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __int__(self):
            '''int QScriptEngine.QObjectWrapOptions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__ixor__(QScriptEngine.QObjectWrapOptions f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __ior__(self, f):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__ior__(QScriptEngine.QObjectWrapOptions f)'''
            return QScriptEngine.QObjectWrapOptions()
        def __iand__(self, mask):
            '''QScriptEngine.QObjectWrapOptions QScriptEngine.QObjectWrapOptions.__iand__(int mask)'''
            return QScriptEngine.QObjectWrapOptions()


class QScriptSyntaxCheckResult():
    """"""
    # Enum QScriptSyntaxCheckResult.State
    Error = 0
    Intermediate = 0
    Valid = 0

    def __init__(self, other):
        '''void QScriptSyntaxCheckResult.__init__(QScriptSyntaxCheckResult other)'''
    def errorMessage(self):
        '''QString QScriptSyntaxCheckResult.errorMessage()'''
        return QString()
    def errorColumnNumber(self):
        '''int QScriptSyntaxCheckResult.errorColumnNumber()'''
        return int()
    def errorLineNumber(self):
        '''int QScriptSyntaxCheckResult.errorLineNumber()'''
        return int()
    def state(self):
        '''QScriptSyntaxCheckResult.State QScriptSyntaxCheckResult.state()'''
        return QScriptSyntaxCheckResult.State()


class QScriptEngineAgent():
    """"""
    # Enum QScriptEngineAgent.Extension
    DebuggerInvocationRequest = 0

    def __init__(self, engine):
        '''void QScriptEngineAgent.__init__(QScriptEngine engine)'''
    def engine(self):
        '''QScriptEngine QScriptEngineAgent.engine()'''
        return QScriptEngine()
    def extension(self, extension, argument = QVariant()):
        '''QVariant QScriptEngineAgent.extension(QScriptEngineAgent.Extension extension, QVariant argument = QVariant())'''
        return QVariant()
    def supportsExtension(self, extension):
        '''bool QScriptEngineAgent.supportsExtension(QScriptEngineAgent.Extension extension)'''
        return bool()
    def exceptionCatch(self, scriptId, exception):
        '''void QScriptEngineAgent.exceptionCatch(int scriptId, QScriptValue exception)'''
    def exceptionThrow(self, scriptId, exception, hasHandler):
        '''void QScriptEngineAgent.exceptionThrow(int scriptId, QScriptValue exception, bool hasHandler)'''
    def positionChange(self, scriptId, lineNumber, columnNumber):
        '''void QScriptEngineAgent.positionChange(int scriptId, int lineNumber, int columnNumber)'''
    def functionExit(self, scriptId, returnValue):
        '''void QScriptEngineAgent.functionExit(int scriptId, QScriptValue returnValue)'''
    def functionEntry(self, scriptId):
        '''void QScriptEngineAgent.functionEntry(int scriptId)'''
    def contextPop(self):
        '''void QScriptEngineAgent.contextPop()'''
    def contextPush(self):
        '''void QScriptEngineAgent.contextPush()'''
    def scriptUnload(self, id):
        '''void QScriptEngineAgent.scriptUnload(int id)'''
    def scriptLoad(self, id, program, fileName, baseLineNumber):
        '''void QScriptEngineAgent.scriptLoad(int id, QString program, QString fileName, int baseLineNumber)'''


class QScriptString():
    """"""
    def __init__(self):
        '''void QScriptString.__init__()'''
    def __init__(self, other):
        '''void QScriptString.__init__(QScriptString other)'''
    def toArrayIndex(self, ok):
        '''int QScriptString.toArrayIndex(bool ok)'''
        return int()
    def toString(self):
        '''QString QScriptString.toString()'''
        return QString()
    def __ne__(self, other):
        '''bool QScriptString.__ne__(QScriptString other)'''
        return bool()
    def __eq__(self, other):
        '''bool QScriptString.__eq__(QScriptString other)'''
        return bool()
    def isValid(self):
        '''bool QScriptString.isValid()'''
        return bool()
    def __hash__(self):
        '''int QScriptString.__hash__()'''
        return int()


class QScriptValue():
    """"""
    # Enum QScriptValue.SpecialValue
    NullValue = 0
    UndefinedValue = 0

    # Enum QScriptValue.PropertyFlag
    ReadOnly = 0
    Undeletable = 0
    SkipInEnumeration = 0
    PropertyGetter = 0
    PropertySetter = 0
    QObjectMember = 0
    KeepExistingFlags = 0
    UserRange = 0

    # Enum QScriptValue.ResolveFlag
    ResolveLocal = 0
    ResolvePrototype = 0
    ResolveScope = 0
    ResolveFull = 0

    def __init__(self):
        '''void QScriptValue.__init__()'''
    def __init__(self, other):
        '''void QScriptValue.__init__(QScriptValue other)'''
    def __init__(self, value):
        '''void QScriptValue.__init__(QScriptValue.SpecialValue value)'''
    def __init__(self, engine, val):
        '''void QScriptValue.__init__(QScriptEngine engine, QScriptValue.SpecialValue val)'''
    def __init__(self, value):
        '''void QScriptValue.__init__(bool value)'''
    def __init__(self, engine, val):
        '''void QScriptValue.__init__(QScriptEngine engine, bool val)'''
    def __init__(self, value):
        '''void QScriptValue.__init__(int value)'''
    def __init__(self, engine, val):
        '''void QScriptValue.__init__(QScriptEngine engine, int val)'''
    def __init__(self, value):
        '''void QScriptValue.__init__(float value)'''
    def __init__(self, engine, val):
        '''void QScriptValue.__init__(QScriptEngine engine, float val)'''
    def __init__(self, value):
        '''void QScriptValue.__init__(QString value)'''
    def __init__(self, engine, val):
        '''void QScriptValue.__init__(QScriptEngine engine, QString val)'''
    def setScriptClass(self, scriptClass):
        '''void QScriptValue.setScriptClass(QScriptClass scriptClass)'''
    def scriptClass(self):
        '''QScriptClass QScriptValue.scriptClass()'''
        return QScriptClass()
    def setData(self, data):
        '''void QScriptValue.setData(QScriptValue data)'''
    def data(self):
        '''QScriptValue QScriptValue.data()'''
        return QScriptValue()
    def construct(self, args = QScriptValueList()):
        '''QScriptValue QScriptValue.construct(list-of-QScriptValue args = QScriptValueList())'''
        return QScriptValue()
    def construct(self, arguments):
        '''QScriptValue QScriptValue.construct(QScriptValue arguments)'''
        return QScriptValue()
    def call(self, thisObject = QScriptValue(), args = QScriptValueList()):
        '''QScriptValue QScriptValue.call(QScriptValue thisObject = QScriptValue(), list-of-QScriptValue args = QScriptValueList())'''
        return QScriptValue()
    def call(self, thisObject, arguments):
        '''QScriptValue QScriptValue.call(QScriptValue thisObject, QScriptValue arguments)'''
        return QScriptValue()
    def propertyFlags(self, name, mode = None):
        '''QScriptValue.PropertyFlags QScriptValue.propertyFlags(QString name, QScriptValue.ResolveFlags mode = QScriptValue.ResolvePrototype)'''
        return QScriptValue.PropertyFlags()
    def propertyFlags(self, name, mode = None):
        '''QScriptValue.PropertyFlags QScriptValue.propertyFlags(QScriptString name, QScriptValue.ResolveFlags mode = QScriptValue.ResolvePrototype)'''
        return QScriptValue.PropertyFlags()
    def setProperty(self, name, value, flags = None):
        '''void QScriptValue.setProperty(QString name, QScriptValue value, QScriptValue.PropertyFlags flags = QScriptValue.KeepExistingFlags)'''
    def setProperty(self, name, value, flags = None):
        '''void QScriptValue.setProperty(QScriptString name, QScriptValue value, QScriptValue.PropertyFlags flags = QScriptValue.KeepExistingFlags)'''
    def setProperty(self, arrayIndex, value, flags = None):
        '''void QScriptValue.setProperty(int arrayIndex, QScriptValue value, QScriptValue.PropertyFlags flags = QScriptValue.KeepExistingFlags)'''
    def property(self, name, mode = None):
        '''QScriptValue QScriptValue.property(QString name, QScriptValue.ResolveFlags mode = QScriptValue.ResolvePrototype)'''
        return QScriptValue()
    def property(self, name, mode = None):
        '''QScriptValue QScriptValue.property(QScriptString name, QScriptValue.ResolveFlags mode = QScriptValue.ResolvePrototype)'''
        return QScriptValue()
    def property(self, arrayIndex, mode = None):
        '''QScriptValue QScriptValue.property(int arrayIndex, QScriptValue.ResolveFlags mode = QScriptValue.ResolvePrototype)'''
        return QScriptValue()
    def setPrototype(self, prototype):
        '''void QScriptValue.setPrototype(QScriptValue prototype)'''
    def prototype(self):
        '''QScriptValue QScriptValue.prototype()'''
        return QScriptValue()
    def strictlyEquals(self, other):
        '''bool QScriptValue.strictlyEquals(QScriptValue other)'''
        return bool()
    def equals(self, other):
        '''bool QScriptValue.equals(QScriptValue other)'''
        return bool()
    def lessThan(self, other):
        '''bool QScriptValue.lessThan(QScriptValue other)'''
        return bool()
    def instanceOf(self, ctor):
        '''bool QScriptValue.instanceOf(QScriptValue ctor)'''
        return bool()
    def toRegExp(self):
        '''QRegExp QScriptValue.toRegExp()'''
        return QRegExp()
    def toDateTime(self):
        '''QDateTime QScriptValue.toDateTime()'''
        return QDateTime()
    def toObject(self):
        '''QScriptValue QScriptValue.toObject()'''
        return QScriptValue()
    def toQMetaObject(self):
        '''QMetaObject QScriptValue.toQMetaObject()'''
        return QMetaObject()
    def toQObject(self):
        '''QObject QScriptValue.toQObject()'''
        return QObject()
    def toVariant(self):
        '''QVariant QScriptValue.toVariant()'''
        return QVariant()
    def toUInt16(self):
        '''int QScriptValue.toUInt16()'''
        return int()
    def toUInt32(self):
        '''int QScriptValue.toUInt32()'''
        return int()
    def toInt32(self):
        '''int QScriptValue.toInt32()'''
        return int()
    def toInteger(self):
        '''float QScriptValue.toInteger()'''
        return float()
    def toBoolean(self):
        '''bool QScriptValue.toBoolean()'''
        return bool()
    def toBool(self):
        '''bool QScriptValue.toBool()'''
        return bool()
    def toNumber(self):
        '''float QScriptValue.toNumber()'''
        return float()
    def toString(self):
        '''QString QScriptValue.toString()'''
        return QString()
    def isError(self):
        '''bool QScriptValue.isError()'''
        return bool()
    def isArray(self):
        '''bool QScriptValue.isArray()'''
        return bool()
    def isRegExp(self):
        '''bool QScriptValue.isRegExp()'''
        return bool()
    def isDate(self):
        '''bool QScriptValue.isDate()'''
        return bool()
    def isObject(self):
        '''bool QScriptValue.isObject()'''
        return bool()
    def isQMetaObject(self):
        '''bool QScriptValue.isQMetaObject()'''
        return bool()
    def isQObject(self):
        '''bool QScriptValue.isQObject()'''
        return bool()
    def isVariant(self):
        '''bool QScriptValue.isVariant()'''
        return bool()
    def isUndefined(self):
        '''bool QScriptValue.isUndefined()'''
        return bool()
    def isString(self):
        '''bool QScriptValue.isString()'''
        return bool()
    def isNull(self):
        '''bool QScriptValue.isNull()'''
        return bool()
    def isFunction(self):
        '''bool QScriptValue.isFunction()'''
        return bool()
    def isNumber(self):
        '''bool QScriptValue.isNumber()'''
        return bool()
    def isBoolean(self):
        '''bool QScriptValue.isBoolean()'''
        return bool()
    def isBool(self):
        '''bool QScriptValue.isBool()'''
        return bool()
    def isValid(self):
        '''bool QScriptValue.isValid()'''
        return bool()
    def engine(self):
        '''QScriptEngine QScriptValue.engine()'''
        return QScriptEngine()
    class ResolveFlags():
        """"""
        def __init__(self):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__init__()'''
            return QScriptValue.ResolveFlags()
        def __init__(self):
            '''int QScriptValue.ResolveFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QScriptValue.ResolveFlags.__init__()'''
        def __bool__(self):
            '''int QScriptValue.ResolveFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QScriptValue.ResolveFlags.__ne__(QScriptValue.ResolveFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QScriptValue.ResolveFlags.__eq__(QScriptValue.ResolveFlags f)'''
            return bool()
        def __invert__(self):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__invert__()'''
            return QScriptValue.ResolveFlags()
        def __and__(self, mask):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__and__(int mask)'''
            return QScriptValue.ResolveFlags()
        def __xor__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__xor__(QScriptValue.ResolveFlags f)'''
            return QScriptValue.ResolveFlags()
        def __xor__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__xor__(int f)'''
            return QScriptValue.ResolveFlags()
        def __or__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__or__(QScriptValue.ResolveFlags f)'''
            return QScriptValue.ResolveFlags()
        def __or__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__or__(int f)'''
            return QScriptValue.ResolveFlags()
        def __int__(self):
            '''int QScriptValue.ResolveFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__ixor__(QScriptValue.ResolveFlags f)'''
            return QScriptValue.ResolveFlags()
        def __ior__(self, f):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__ior__(QScriptValue.ResolveFlags f)'''
            return QScriptValue.ResolveFlags()
        def __iand__(self, mask):
            '''QScriptValue.ResolveFlags QScriptValue.ResolveFlags.__iand__(int mask)'''
            return QScriptValue.ResolveFlags()
    class PropertyFlags():
        """"""
        def __init__(self):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__init__()'''
            return QScriptValue.PropertyFlags()
        def __init__(self):
            '''int QScriptValue.PropertyFlags.__init__()'''
            return int()
        def __init__(self):
            '''void QScriptValue.PropertyFlags.__init__()'''
        def __bool__(self):
            '''int QScriptValue.PropertyFlags.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QScriptValue.PropertyFlags.__ne__(QScriptValue.PropertyFlags f)'''
            return bool()
        def __eq__(self, f):
            '''bool QScriptValue.PropertyFlags.__eq__(QScriptValue.PropertyFlags f)'''
            return bool()
        def __invert__(self):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__invert__()'''
            return QScriptValue.PropertyFlags()
        def __and__(self, mask):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__and__(int mask)'''
            return QScriptValue.PropertyFlags()
        def __xor__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__xor__(QScriptValue.PropertyFlags f)'''
            return QScriptValue.PropertyFlags()
        def __xor__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__xor__(int f)'''
            return QScriptValue.PropertyFlags()
        def __or__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__or__(QScriptValue.PropertyFlags f)'''
            return QScriptValue.PropertyFlags()
        def __or__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__or__(int f)'''
            return QScriptValue.PropertyFlags()
        def __int__(self):
            '''int QScriptValue.PropertyFlags.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__ixor__(QScriptValue.PropertyFlags f)'''
            return QScriptValue.PropertyFlags()
        def __ior__(self, f):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__ior__(QScriptValue.PropertyFlags f)'''
            return QScriptValue.PropertyFlags()
        def __iand__(self, mask):
            '''QScriptValue.PropertyFlags QScriptValue.PropertyFlags.__iand__(int mask)'''
            return QScriptValue.PropertyFlags()


class QScriptValueIterator():
    """"""
    def __init__(self, value):
        '''void QScriptValueIterator.__init__(QScriptValue value)'''
    def scriptName(self):
        '''QScriptString QScriptValueIterator.scriptName()'''
        return QScriptString()
    def toBack(self):
        '''void QScriptValueIterator.toBack()'''
    def toFront(self):
        '''void QScriptValueIterator.toFront()'''
    def remove(self):
        '''void QScriptValueIterator.remove()'''
    def flags(self):
        '''QScriptValue.PropertyFlags QScriptValueIterator.flags()'''
        return QScriptValue.PropertyFlags()
    def setValue(self, value):
        '''void QScriptValueIterator.setValue(QScriptValue value)'''
    def value(self):
        '''QScriptValue QScriptValueIterator.value()'''
        return QScriptValue()
    def name(self):
        '''QString QScriptValueIterator.name()'''
        return QString()
    def previous(self):
        '''void QScriptValueIterator.previous()'''
    def hasPrevious(self):
        '''bool QScriptValueIterator.hasPrevious()'''
        return bool()
    def next(self):
        '''void QScriptValueIterator.next()'''
    def hasNext(self):
        '''bool QScriptValueIterator.hasNext()'''
        return bool()


class QString():
    """"""
    def __init__(self):
        '''QScriptString QString.__init__()'''
        return QScriptString()


def qScriptDisconnect(sender, signal, receiver, function):
    '''static bool qScriptDisconnect(QObject sender, SIGNAL() signal, QScriptValue receiver, QScriptValue function)'''
    return bool()

def qScriptConnect(sender, signal, receiver, function):
    '''static bool qScriptConnect(QObject sender, SIGNAL() signal, QScriptValue receiver, QScriptValue function)'''
    return bool()

